<?php
/*
Plugin Name: Smart Helpbot Popup
Plugin URI:  https://bitcraftx.com/
Description: Smart Helpbot Popup is an intuitive WordPress plugin that enhances user engagement by displaying a dynamic chat popup on your website.
Version:     1.0.0
Author:      Bitcraftx
Author URI:  https://bitcraftx.com/
License: GPL-2.0-or-later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: smart-helpbot-popup
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class bitcx_smart_helpbot_popup {

    // seetings
    
    public $selected_pages = array();
    public $selected_posts = array();
    public $enable_popup;
    public $all_pages;
    public $all_posts;
    public $popup_btn_bg;
    public $popup_btn_hover_bg;
    public $popup_btn_txt;
    public $popup_btn_hover_txt;
    public $popup_btn_border;
    public $popup_bg;
    public $popup_border;
    public $popup_link_clr;
    public $popup_icon;

    public function __construct() {
        global $pagenow;

        define('BITCX_HELPBOT_IMAGES_URL', plugin_dir_url(__FILE__) . 'assets/images/');
        
        register_activation_hook( __FILE__, array($this, 'bitcx_wp_helpbot_activate'));
        //register_deactivation_hook( __FILE__, array($this, 'wp_helpbot_deactivate'));

        // Style
        $style_sheet = plugin_dir_path(__FILE__).'assets/css/style.css';
        wp_enqueue_style( 'smart-helpbot-popup-style', plugins_url( '/assets/css/style.css', __FILE__ ), array(), filemtime( $style_sheet ), 'all' );

        // Admin options
        add_action('admin_menu', array($this, 'bitcx_wp_helpbot_admin_menu'));

        // Popup
        add_action('wp_footer', array($this, 'bitcx_call_chat_popup'));

        // Popup content
        add_action( 'wp_ajax_bitcx_ajax_get_chat_response', array($this, 'bitcx_ajax_get_chat_response') );
        add_action( 'wp_ajax_nopriv_bitcx_ajax_get_chat_response', array($this, 'bitcx_ajax_get_chat_response') );

        // ajax
        add_action( 'wp_ajax_bitcx_reset_wordpress_chatpopup_configurations', array($this,  'bitcx_reset_wordpress_chatpopup_configurations') );
        add_action( 'wp_ajax_nopriv_bitcx_reset_wordpress_chatpopup_configurations', array($this,  'bitcx_reset_wordpress_chatpopup_configurations') );
        // Load more ajax
        add_action( 'wp_ajax_bitcx_loadmore_posts', array($this,  'bitcx_loadmore_posts') );
        add_action( 'wp_ajax_nopriv_bitcx_loadmore_posts', array($this,  'bitcx_loadmore_posts') );
    }

    public function bitcx_loadmore_posts(){
        if (isset( $_POST['security'] )) 
        {
            $nonce = sanitize_text_field( wp_unslash( $_POST['security'] ) );
            if ( ! wp_verify_nonce( $nonce, 'bitcx_nonce' ) ) 
            {
                return;
            }else{
                if(isset($_POST['term']) && isset($_POST['offset'])){
                    $term_id = sanitize_text_field( wp_unslash( $_POST['term'] ) );
                    $offset = sanitize_text_field( wp_unslash( $_POST['offset'] ) );
                    $data = $this->bitcx_get_posts_by_terms($term_id, $offset);
                    wp_send_json($data);
                }
            }
        }
        wp_die();
    }

    public function bitcx_reset_wordpress_chatpopup_configurations() {
        if (isset( $_POST['security'] )) 
        {
            $nonce = sanitize_text_field( wp_unslash( $_POST['security'] ) );
            if ( ! wp_verify_nonce( $nonce, 'wcp_ajax_nonce' ) ) 
            {
                return;
            }else{
                update_option('chatpop_enable', sanitize_key(0));
                update_option('chatpop_all_pages', sanitize_key(1));
                update_option('chatpop_all_pages', sanitize_key(1));
                update_option('chatpop_all_posts', sanitize_key(1));
                update_option('chatpop_selected_pages', sanitize_key(array()));
                update_option('chatpop_selected_posts', sanitize_key(array()));
            }
        }

        wp_die();
    }

    public function bitcx_wp_helpbot_activate(){

        if(get_option('chatpop_enable') === false){
            add_option('chatpop_enable', 0);
        }

        if(get_option('chatpop_all_pages') === false){
            add_option('chatpop_all_pages', 0 );
        }
        
        if(get_option('chatpop_selected_pages') === false){
            add_option('chatpop_selected_pages', array());
        }

        if(get_option('chatpop_all_posts') === false){
            add_option('chatpop_all_posts', 0);
        }

        if(get_option('chatpop_selected_posts') === false){
            add_option('chatpop_selected_posts', array());
        }

        if(get_option('chatpop_opt_bg_color') === false){
            add_option('chatpop_opt_bg_color', '#fff');
        }

        if(get_option('chatpop_opt_bg_hover_color') === false){
            add_option('chatpop_opt_bg_hover_color', '#000');
        }

        if(get_option('chatpop_opt_txt_color') === false){
            add_option('chatpop_opt_txt_color', '#000');
        }

        if(get_option('chatpop_opt_hover_txt_color') === false){
            add_option('chatpop_opt_hover_txt_color', '#fff');
        }

        if(get_option('chatpop_opt_border_color') === false){
            add_option('chatpop_opt_border_color', '#000');
        }

        if(get_option('chatpop_bg_color') === false){
            add_option('chatpop_bg_color', '#fff');
        }

        if(get_option('chatpop_border_color') === false){
            add_option('chatpop_border_color', '#000');
        }

        if(get_option('chatpop_link_color') === false){
            add_option('chatpop_link_color', '#000');
        }

        if(get_option('chatpop_icon') === false){
            add_option('chatpop_icon', 'chat-1.png');
        }
    }
    
    public function bitcx_wp_helpbot_deactivate() {}

    public function bitcx_wp_helpbot_admin_menu() {
        add_menu_page(
            'Smart Helpbot Popup',
            'Smart Helpbot Popup',
            'manage_options',
            'smart-helpbot-popup',
            array($this, 'bitcx_wp_helpbot_admin_menu_settings'),
            'dashicons-admin-generic',
            100
        );
    }

    public function bitcx_wp_helpbot_admin_menu_settings(){
        if ( ! current_user_can( 'manage_options' ) ) {
            return;
        }
        
        $select2_css = plugin_dir_path(__FILE__).'assets/css/select2.min.css';
        wp_enqueue_style('select2-css', plugins_url( '/assets/css/select2.min.css', __FILE__ ), array(), filemtime( $select2_css ));
        $select2_js = plugin_dir_path(__FILE__).'assets/js/admin/select2.min.js';
        wp_enqueue_script('select2-js', plugins_url( '/assets/js/admin/select2.min.js', __FILE__ ), array(), filemtime( $select2_js ), true );
        $admin_js = plugin_dir_path(__FILE__).'assets/js/admin/admin-script.js';
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_script( 'smart-helpbot-popup-admin-script', plugins_url( '/assets/js/admin/admin-script.js', __FILE__ ), array('wp-color-picker'), filemtime( $admin_js ), true);
        wp_localize_script( 'smart-helpbot-popup-admin-script', 'wcpa_object', array(
            'ajax_url' => admin_url( 'admin-ajax.php' ),
            'nonce'    => wp_create_nonce( 'wcp_ajax_nonce' )
        ));

        // template
        include(plugin_dir_path(__FILE__) . 'templates/admin/settings.php');
    }

    public function bitcx_call_chat_popup()
    {
        global $post;
        $display_popup = false;
        $post_ids = array();
        $this->enable_popup = get_option('chatpop_enable');
        $this->all_pages = get_option('chatpop_all_pages');
        $this->all_posts = get_option('chatpop_all_posts');
        $this->selected_pages = get_option('chatpop_selected_pages');
        $this->selected_posts = get_option('chatpop_selected_posts');

        if($this->enable_popup == 0){
            return;
        }

        // Pages
        if(is_page() || is_front_page()){
            if($this->all_pages == 1)
            {   // All pages case
                if(is_front_page() || is_page())
                {
                    $this->bitcx_include_popup();        
                }
            }else if($this->all_pages == 0){
                // Selective pages
                if(in_array($post->ID, $this->selected_pages)){
                    $this->bitcx_include_popup();
                }
            }
        }

        // Posts
        if ( is_singular('post') || is_archive()) {
            if($this->all_posts == 1){
                // All posts
                if(is_archive() || is_single())
                {
                    $this->bitcx_include_popup();
                }
            }else if($this->all_posts == 0){
                // Selective posts
                if(in_array($post->ID, $this->selected_posts)){
                    $this->bitcx_include_popup();
                }
            }
        }
    }

    public function bitcx_include_popup()
    {

        // template
        include(plugin_dir_path(__FILE__) . 'templates/public/popup.php');

        wp_enqueue_script( 'jquery' );
        $script_js = plugin_dir_path(__FILE__).'assets/js/public/custom-script.js';
        wp_enqueue_script( 'bitcx-custom-script', plugins_url( '/assets/js/public/custom-script.js', __FILE__ ), array(), filemtime( $script_js ), true );
        wp_localize_script('bitcx-custom-script', 'bitcx_object', array(
            'ajax_url' => admin_url('admin-ajax.php'),
            'nonce'    => wp_create_nonce('bitcx_nonce')
        ));

    }

    public function bitcx_ajax_get_chat_response(){
        if (isset( $_POST['security'] )) 
        {
            $nonce = sanitize_text_field( wp_unslash( $_POST['security'] ) );
            if ( ! wp_verify_nonce( $nonce, 'bitcx_nonce' ) ) 
            {
                return;
            }else
            {
                if(isset($_POST['term_id']) && isset($_POST['term_name']))
                {   
                    $term_id = sanitize_text_field(wp_unslash($_POST['term_id']));
                    $term_name = sanitize_text_field(wp_unslash($_POST['term_name']));
                    $transient_key = 'bitcx_helpbot_data'.$term_id;
                    $transient_data = get_transient( $transient_key );

                    // if ( false === $transient_data )
                    // {

                        $popup_btn_bg = get_option('chatpop_opt_bg_color');
                        $popup_btn_txt = get_option('chatpop_opt_txt_color');
                        $popup_btn_border = get_option('chatpop_opt_border_color');
                        $popup_btn_hover_bg = get_option('chatpop_opt_bg_hover_color');
                        $popup_btn_hover_txt = get_option('chatpop_opt_hover_txt_color');

                        $data = array(
                            'terms' => array(),
                            'posts' => array()
                        );

                        $td = '';
                        $child_terms = get_term_children($term_id, 'category');
                        if (!empty($child_terms) && !is_wp_error($child_terms)) {
                            $td .= '<h5 class="bitcx-exp">'.esc_html('Explore More topics in: ').'<u>'.$term_name.'</u></h5>';
                            foreach ($child_terms as $child) {
                                $ct = get_term_by('id', $child, 'category');
                                $td .= '<a bg-color="'.$popup_btn_bg.'" border-color="'.$popup_btn_border.'" text-color="'.$popup_btn_txt.'" hover-bg-color="'.$popup_btn_hover_bg.'" hover-text-color="'.$popup_btn_hover_txt.'" data-type="child" class="bitcx-option" href="#" data-id="'.esc_html($ct->term_id).'">'.esc_html($ct->name).'</a>';
                            }
                            $data['terms'] = $td;
                        }
                        
                        $data['posts'] = $this->bitcx_get_posts_by_terms($term_id);
                        set_transient( $transient_key, $data, HOUR_IN_SECONDS );
                    // }else{
                    //     $data = $transient_data;
                    // }
                }
            }
        }
        wp_send_json($data);
    }

    public function bitcx_get_posts_by_terms($term_id, $offset=false){
        $data = array();
        $link_clr = get_option('chatpop_link_color');
        $pp=2;
        $params = array(
            'post_type' => 'post',
            'posts_per_page' => $pp,
            'offset'         => 0,
            'tax_query' => array(
                array(
                    'taxonomy' => 'category',
                    'field'    => 'id',
                    'terms'    => $term_id
                ),
            ),
            'orderby'        => 'title',
            'order'          => 'ASC',
        );
        if($offset == false){
            $offset = 0;
        }
        $offset = $offset+$pp;

        $cache_key = "bitcx_posts_{$term_id}_{$pp}_{$offset}";
        $cached_posts = wp_cache_get($cache_key, 'bitcx_cached_posts');
        if($cached_posts === false){
            $posts = new WP_Query( $params );
            $post_count = $posts->found_posts;
            if ( !empty($posts->posts) ) {
                foreach($posts->posts as $post){
                    $data[] = '<a data-color="'.$link_clr.'" class="bitcx-post" target="_blank" href="'.get_the_permalink($post->ID).'">- '.$post->post_title.'</a>';
                }
                if($post_count > $pp && $offset < $post_count){
                    $data[] = '<a class="bitcx-loadmore-posts" data-term="'.$term_id.'" data-offset="'.$offset.'" data-count="'.$post_count.'" href="#">'.esc_html('Load more').'</a>';
                }
            }else{
                $data[] = esc_html('No more data!');
            }
            wp_cache_set($cache_key, $data, 'bitcx_cached_posts', 3600);
        }else{
            $data = $cached_posts;
        }
        return implode("", $data);
    }

    // public function bitcx_get_posts_by_terms($term_id, $offset=false){
    //     $data = array();
    //     global $wpdb;
    //     $post_count = $this->bitcx_get_post_count($term_id);
    //     $link_clr = get_option('chatpop_link_color');
    //     $pp=2;
    //     $query = '';
    //     $cache_key = "bitcx_posts_{$term_id}_{$pp}_{$offset}";
    //     $cached_data = wp_cache_get($cache_key, 'bitcx_cached_group');
        
    //     if ($cached_data === false) {
    //         $sql = "
    //             SELECT p.*
    //             FROM {$wpdb->posts} AS p
    //             INNER JOIN {$wpdb->term_relationships} AS tr ON p.ID = tr.object_id
    //             INNER JOIN {$wpdb->term_taxonomy} AS tt ON tr.term_taxonomy_id = tt.term_taxonomy_id
    //             WHERE tt.term_id = {$term_id}
    //             AND tt.taxonomy = %s
    //             AND p.post_status = %s
    //             AND p.post_type = %s
    //             ORDER BY p.post_date DESC
    //             LIMIT %d
    //         ";
            
    //         if($offset != false){
    //         $sql = $sql." OFFSET %d";
    //         $query = $wpdb->prepare($sql, 'category', 'publish', 'post', $pp, $offset);
    //         }else{
    //             $query = $wpdb->prepare($sql, 'category', 'publish', 'post', $pp);
    //         }

    //         $offset = $offset+$pp;
    //         $posts = $wpdb->get_results($query);
    //         wp_cache_set($cache_key, $posts, 'bitcx_cached_group', 3600);
    //     }else{
    //         $posts = $cached_data;
    //     }

    //     if ( !empty($posts) ) {
    //         foreach($posts as $post){
    //             $data[] = '<a data-color="'.$link_clr.'" class="bitcx-post" target="_blank" href="'.get_the_permalink($post->ID).'">- '.esc_html($post->post_title).'</a>';
    //         }
    //         if($post_count > $pp && $offset < $post_count){
    //             $data[] = '<a class="bitcx-loadmore-posts" data-term="'.$term_id.'" data-offset="'.$offset.'" data-count="'.$post_count.'" href="#">'.esc_html('Load more').'</a>';
    //         }
    //         wp_reset_postdata();
    //     }else{
    //         $data[] = esc_html('No more data!');
    //     }
    //     return implode("", $data);
    // }

    // public function bitcx_get_post_count($term_id){
    //     $cache_key = "bitcx_posts_{$term_id}_count";
    //     $cached_count = wp_cache_get($cache_key, 'bitcx_cached_group_count');
    //     if($cached_count === false){
    //         global $wpdb;
    //         $total_count_query = $wpdb->prepare("
    //             SELECT COUNT(*)
    //             FROM {$wpdb->posts} AS p
    //             INNER JOIN {$wpdb->term_relationships} AS tr ON p.ID = tr.object_id
    //             INNER JOIN {$wpdb->term_taxonomy} AS tt ON tr.term_taxonomy_id = tt.term_taxonomy_id
    //             WHERE tt.term_id = %d
    //             AND tt.taxonomy = %s
    //             AND p.post_status = %s
    //             AND p.post_type = %s
    //         ", $term_id, 'category', 'publish', 'post');
    //         $count = $wpdb->get_var($total_count_query);
    //         wp_cache_set($cache_key, $count, 'bitcx_cached_group_count', 3600);
    //     }else{
    //         $count = $cached_count;
    //     }
    //     return $count;
    // }
}
$wp_helpbot = new bitcx_smart_helpbot_popup();