<?php
    $pages = get_pages();
    $args = array(
        'post_type'      => 'post',
        'posts_per_page' => 10,
        'orderby'        => 'date',
        'order'          => 'DESC',
    );
    $posts = get_posts($args);
    
    if (isset($_POST['save_settings'])) 
    {   
        if(isset($_POST['wcp_save_nonce']))
        {   
            $nonce = sanitize_text_field( wp_unslash( $_POST['wcp_save_nonce'] ) );
            if ( !isset( $_POST['wcp_save_nonce'] ) || !wp_verify_nonce( $nonce, 'wcp_save_nonce_action' ) ) 
            {   
                return;
            }else
            {   
                $selected_pages = array();
                $selected_posts = array();
                $enable = 1;

                if(!isset($_POST['enable-popup']) && $_POST['enable-popup'] == ''){
                    $enable = 0;
                }else{
                    $enable = sanitize_key($_POST['enable-popup']);
                }

                if(isset($_POST['all-pages']))
                {
                    $all_pages = sanitize_key($_POST['all-pages']);
                    if(isset($_POST['selected-pages']) && !empty($_POST['selected-pages'])){
                        $selected_pages = array_map( 'sanitize_text_field', wp_unslash($_POST['selected-pages']));
                    }
                }
                
                if(isset($_POST['all-posts']))
                {
                    $all_posts = sanitize_key($_POST['all-posts']);
                    if(isset($_POST['selected-posts']) && !empty($_POST['selected-posts'])){
                        $selected_posts = array_map( 'sanitize_text_field', wp_unslash($_POST['selected-posts']));
                    }
                }

                $output = array();
                $output[] = update_option('chatpop_enable', $enable);
                $output[] = update_option('chatpop_all_pages', $all_pages);
                $output[] = update_option('chatpop_all_posts', $all_posts);

                if(!empty($selected_pages)){
                    $output[] = update_option('chatpop_selected_pages', $selected_pages);
                }
                
                if(!empty($selected_posts)){
                    $output[] = update_option('chatpop_selected_posts', $selected_posts);
                }

                if(!empty(isset($_POST['popup-bg-color']))){
                    $output[] = update_option('chatpop_bg_color', sanitize_hex_color(wp_unslash($_POST['popup-bg-color'])));
                }

                if(!empty(isset($_POST['popup-border-color']))){
                    $output[] = update_option('chatpop_border_color', sanitize_hex_color(wp_unslash($_POST['popup-border-color'])));
                }

                if(!empty(isset($_POST['popup-opt-bg-color']))){
                    $output[] = update_option('chatpop_opt_bg_color', sanitize_hex_color(wp_unslash($_POST['popup-opt-bg-color'])));
                }

                if(!empty(isset($_POST['popup-opt-bg-hover-color']))){
                    $output[] = update_option('chatpop_opt_bg_hover_color', sanitize_hex_color(wp_unslash($_POST['popup-opt-bg-hover-color'])));
                }

                if(!empty(isset($_POST['popup-opt-txt-color']))){
                    $output[] = update_option('chatpop_opt_txt_color', sanitize_hex_color(wp_unslash($_POST['popup-opt-txt-color'])));
                }

                if(!empty(isset($_POST['popup-opt-hover-txt-color']))){
                    $output[] = update_option('chatpop_opt_hover_txt_color', sanitize_hex_color(wp_unslash($_POST['popup-opt-hover-txt-color'])));
                }

                if(!empty(isset($_POST['popup-opt-border-color']))){
                    $output[] = update_option('chatpop_opt_border_color', sanitize_hex_color(wp_unslash($_POST['popup-opt-border-color'])));
                }

                if(!empty(isset($_POST['popup-link-color']))){
                    $output[] = update_option('chatpop_link_color', sanitize_hex_color(wp_unslash($_POST['popup-link-color'])));
                }

                if(!empty(isset($_POST['popup-icon']))){
                    $output[] = update_option('chatpop_icon', sanitize_text_field(wp_unslash($_POST['popup-icon'])));
                }
                
                $message = 'Configurations added successfully!';
                $nc = 'success';

                // message
                echo '<div class="notice bitcx notice-'.esc_html($nc).' is-dismissible">'.esc_html($message).'</div>';
            }
        }
    }

    $enable_popup = get_option('chatpop_enable');
    $all_pages = get_option('chatpop_all_pages');
    $selected_pages = get_option('chatpop_selected_pages');
    $all_posts = get_option('chatpop_all_posts');
    $selected_posts = get_option('chatpop_selected_posts');
    $popup_btn_bg = get_option('chatpop_opt_bg_color');
    $popup_btn_hover_bg = get_option('chatpop_opt_bg_hover_color');
    $popup_btn_txt = get_option('chatpop_opt_txt_color');
    $popup_btn_hover_txt = get_option('chatpop_opt_hover_txt_color');
    $popup_btn_border = get_option('chatpop_opt_border_color');
    $popup_bg = get_option('chatpop_bg_color');
    $popup_border = get_option('chatpop_border_color');
    $popup_link_clr = get_option('chatpop_link_color');
    $popup_icon = get_option('chatpop_icon');

?>

<h1 class="wcp-header"><?php echo esc_html('Helpbot Configurations'); ?></h1>
<form method="POST" class="bitcs-helpbot-form">
    <?php wp_nonce_field( 'wcp_save_nonce_action', 'wcp_save_nonce' ); ?>
    <table class="bitcx-table">
        <tr>
            <th><?php esc_attr_e( 'Enable', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <select name="enable-popup">
                    <option value="1" <?php echo ($enable_popup == 1) ? 'selected' : ''; ?>><?php esc_attr_e( 'Yes', 'smart-helpbot-popup' ); ?></option>
                    <option value="0" <?php echo ($enable_popup == 0) ? 'selected' : ''; ?>><?php esc_attr_e( 'No', 'smart-helpbot-popup' ); ?></option>
                </select>
            </td>
        </tr>
        <!-- Pages -->
        <tr>
            <th><?php esc_attr_e( 'Pages', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <label><input type="radio" class="all-pages" name="all-pages" value="1" <?php echo ($all_pages == 1) ? 'checked' : ''; ?>><?php esc_attr_e( 'All', 'smart-helpbot-popup' ); ?></label>
                <label><input type="radio" class="all-pages" name="all-pages" value="0" <?php echo ($all_pages == 0) ? 'checked' : ''; ?>><?php esc_attr_e( 'Selected', 'smart-helpbot-popup' ); ?></label>
            </td>
        </tr>
        <tr class="pages-selection-tr <?php echo ($all_pages == 1) ? 'display-none' : ''; ?>">
            <th></th>
            <td>
                <?php if(!empty($pages)){ ?>
                <select class="select2 pages-multiselect bitcx" multiple="multiple" name="selected-pages[]">
                    <?php foreach($pages as $page){ ?>
                    <option value="<?php echo esc_html($page->ID); ?>" <?php echo (!empty($selected_pages) && in_array($page->ID, $selected_pages)) ? 'selected' : ''; ?>><?php echo esc_html($page->post_title); ?></option>
                    <?php } ?>
                </select>
                <?php } ?>
            </td>
        </tr>
        <tr><th></th><td></td></tr>
        <!-- Posts -->
        <tr>
            <th><?php esc_attr_e( 'Posts', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <label><input type="radio" class="all-posts" name="all-posts" value="1" <?php echo ($all_posts == 1) ? 'checked' : ''; ?>><?php esc_attr_e( 'All', 'smart-helpbot-popup' ); ?></label>
                <label><input type="radio" class="all-posts" name="all-posts" value="0" <?php echo ($all_posts == 0) ? 'checked' : ''; ?>><?php esc_attr_e( 'Selected', 'smart-helpbot-popup' ); ?></label>
            </td>
        </tr>
        <tr class="posts-selection-tr <?php echo ($all_posts == 1) ? 'display-none' : ''; ?>">
            <th></th>
            <td>
                <?php if(!empty($posts)){ ?>
                <select class="select2 posts-multiselect bitcx" multiple="multiple" name="selected-posts[]">
                    <?php foreach($posts as $post){ ?>
                    <option value="<?php echo esc_html($post->ID); ?>" <?php echo (!empty($selected_posts) && in_array($post->ID, $selected_posts)) ? 'selected' : ''; ?>><?php echo esc_html($post->post_title); ?></option>
                    <?php } ?>
                </select>
                <?php } ?>
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Popup background color', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <input type="text" id="popup_bg_color" name="popup-bg-color" value="<?php echo esc_attr( (!empty($popup_bg)) ? $popup_bg : '#fff' ); ?>" class="popup-bg-color" />
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Popup border color', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <input type="text" id="popup_border_color" name="popup-border-color" value="<?php echo esc_attr( (!empty($popup_border)) ? $popup_border : '#000' ); ?>" class="popup-border-color" />
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Popup options background color', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <input type="text" id="popup_opt_bg_color" name="popup-opt-bg-color" value="<?php echo esc_attr( (!empty($popup_btn_bg)) ? $popup_btn_bg : '#fff' ); ?>" class="popup-opt-bg-color" />
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Popup options hover background color', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <input type="text" id="popup_opt_hover_bg_color" name="popup-opt-bg-hover-color" value="<?php echo esc_attr( (!empty($popup_btn_hover_bg)) ? $popup_btn_hover_bg : '#000' ); ?>" class="popup-opt-bg-hover-color" />
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Popup options text color', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <input type="text" id="popup_opt_txt_color" name="popup-opt-txt-color" value="<?php echo esc_attr( (!empty($popup_btn_txt)) ? $popup_btn_txt : '#000' ); ?>" class="popup-opt-txt-color" />
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Popup options hover text color', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <input type="text" id="popup_opt_hover_txt_color" name="popup-opt-hover-txt-color" value="<?php echo esc_attr( (!empty($popup_btn_hover_txt)) ? $popup_btn_hover_txt : '#000' ); ?>" class="popup-opt-hover-txt-color" />
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Popup options border color', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <input type="text" id="popup_opt_border_color" name="popup-opt-border-color" value="<?php echo esc_attr( (!empty($popup_btn_border)) ? $popup_btn_border : '#000' ); ?>" class="popup-opt-border-color" />
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Popup link text color', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <input type="text" id="popup_opt_link_color" name="popup-link-color" value="<?php echo esc_attr( (!empty($popup_link_clr)) ? $popup_link_clr : '#000' ); ?>" class="popup-link-color" />
            </td>
        </tr>
        <tr>
            <th><?php esc_attr_e( 'Chat icon', 'smart-helpbot-popup' ); ?>:</th>
            <td>
                <?php 
                $icons = array(
                    'chat-1.png',
                    'chat-2.png',
                    'chat-3.png',
                    'chat-4.png'
                );
                foreach($icons as $icon){
                    ?>
                    <p>
                        <label>
                            <input type="radio" name="popup-icon" value="<?php echo esc_attr($icon); ?>" <?php if($icon == $popup_icon){ echo "checked"; } ?>> 
                            <img width="40px" src="<?php echo esc_url(BITCX_HELPBOT_IMAGES_URL . esc_attr($icon)); ?>">
                        </label>
                    </p>
                    <?php
                }
                ?>
            </td>
        </tr>
    </table>
    <input type="submit" class="bitcx-submit" name="save_settings" value="Submit">
    <a class="bitcx-reset" href="#">Reset</a>
</form>